@@ -11,7 +11,7 @@ use CPAN::Packager::Util;
 use Log::Log4perl qw(:easy);
 use Try::Tiny;
 
-our $VERSION = '0.24';
+our $VERSION = '0.30';
 
 has 'builder' => (
     is       => 'rw',
@@ -101,12 +101,15 @@ sub _build_dependency_analyzer {
     $self->dependency_analyzer($dependency_analyzer);
 }
 
+our $config;
 sub make {
     my ( $self, $module, $built_modules ) = @_;
     die 'module must be passed' unless $module;
     INFO("### Building packages for $module ...");
-    my $config = $self->config_loader->load( $self->conf );
-    $config->{modules} = $built_modules if $built_modules;
+    $config = $self->config_loader->load( $self->conf ) unless $config;
+    if($built_modules) {
+        $config = $self->merge_config( $built_modules, $config );
+    }
     $config->{global}->{verbose} = $self->verbose;
 
     INFO("### Analyzing dependencies for $module ...");
@@ -137,7 +140,7 @@ sub make {
         }
         catch {
             $self->_dump_modules( "Sorted modules", $sorted_modules );
-            LOGDIE( "### Built packages for $module faied :-(" . $_);
+            LOGDIE( "### Built packages for $module faied :-(. Cause: " . $_);
         };
     }
 
@@ -199,10 +202,19 @@ sub build_modules {
             die("$module->{module} failed");
         }
     }
-    my %modules
-        = map { exists $_->{module} ? { $_->{module} => $_ } : $_ => $_; }
-        @{$modules};
-    return \%modules;
+
+    my $built_modules = {};
+    foreach my $module (@{$modules}) {
+        if(exists $module->{module}) {
+            $built_modules->{$module->{module}} = $module; 
+        } elsif (exists $module->{original_module}) {
+            $built_modules->{$module->{original_module}} = $module; 
+        } else {
+            $built_modules->{$module} = $module;
+        }
+    }
+
+    return $built_modules; 
 }
 
 sub analyze_module_dependencies {
