@@ -3,6 +3,7 @@ use strict;
 use warnings;
 use CPAN::Packager::Config::Schema;
 use Kwalify;
+use Log::Log4perl qw(:easy);
 
 sub validate {
     my ( $class, $config ) = @_;
@@ -19,8 +20,7 @@ sub _validate_config {
         }
     }
     else {
-        warn "Kwalify is not installed. Skipping the config validation."
-            if $^W;
+        WARN("Kwalify is not installed. Skipping the config validation.");
     }
 }
 
